#!/usr/bin/perl

use File::Basename;
use Getopt::Std;
use Net::hostent;
use Sys::Hostname;
use Socket;
use Cwd 'abs_path';
use lib "@INC/../../lib";
use PerlLog;
use ConfigRegistry;
use Properties;
use Interp;
use Database::DB2;
use lib @libdir;


BEGIN {

    # Determining the location of the TDW libraries
    ($progname, $rundir) = fileparse($0);
    $rundir =~ s/\\/\//g;
    $topdir = abs_path("$rundir/../..");
    push(@libdir,"$topdir/tools/lib");
    push(@INC, "$topdir/tools/lib");

}



select (STDERR);$| = 1;
select (STDOUT);$| = 1;

my $ctrldb = "TWH_MD";
my $ctrluser = "";
my $ctrlpass = "";
my $localsystem;
my $interp;
my @list;
my $logger = new PerlLog;
my $configreg;
my $hostname = "";
my $state = "A"; 
my $getpws = 0;

$LogPropDir = $topdir . "/logginglocation";

if ( ! -d $LogPropDir )
{
    $topdir = $ENV{TWH_TOPDIR};
    $topdir =~ s/\\/\//g;
    $LogPropDir = $topdir . "/logginglocation";
}

my $CommonLogDir = $logger->getCommonLogDir($LogPropDir);
my $logdir = $CommonLogDir . "/cdw/logs/install";
my $tmpdir = $CommonLogDir . "/cdw/temp/tools";

$configreg = new ConfigRegistry($logger, "$topdir", "$tmpdir");


getCtrlProps();


$twh_topdir = "$ENV{TWH_TOPDIR}" or die "TWH_TOPDIR environment variable not defined.";
$appdir = "$twh_topdir" . "/apps/anm";
$scriptpath = "$appdir/" . "v1212/misc";
$miscpath  = "$appdir/" . "v1212/misc";
$tmpsrc = "$tmpdir/tmp_src";
$tmplog = "$tmpdir/tmp_log";


$create_view = "$miscpath" . "/create_view";

logit("Invoking the create view script.");
my $rc = runexecsql("$create_view","$logdir/create_view.log");

if($rc) {
    logit("An error occurred when attempting to execute the create view script!");
    exit $rc;
}

##Subroutines...

sub getCtrlProps {


    my $propfile = new Properties($logger, "$topdir", ".mddb.properties");

    $ctrluser = $propfile->getProperty("userid");
    $ctrlpass = $propfile->getProperty("password");
    if ( $interp ne "w32-ix86" )
    {
        $ctrlpass =~ s/\$/\\\$/g;
    }

    my $mddbobj = new Database::DB2($logger);
    $mddbobj->add_object("DBUSER", $ctrluser);
    $mddbobj->add_object("DBPASS", $ctrlpass);

    $mddbobj->db_exec("db2start");
    $propfile->manage_wh_svcs("start");
}



sub logit {
    
   my $logmsg=shift;
   
   my $logfile="$logdir/create_view.log";
   open (LOG, ">>$logfile") or die "cannot open $logfile!";
   my $date=localtime;
   print LOG "$date: $logmsg\n";
   close LOG;
   
}

sub runexecsql {
	
    my $script=shift;
    my $log=shift;
    my $log="$logdir/create_view.log";
    my $rc;
    
    if ( -d "c:/" ) {
        my $cmd="\"$twh_topdir/tools/bin/execsql\" \"$script\" \"$log\" \"TWH_MART\" \"$ctrluser\" \"$ctrlpass\" \"TWH_MART\" \"$ctrluser\" \"$ctrlpass\"";
        `\"$cmd\"`;

        $rc = $?;


    } else {
        my $cmd="$twh_topdir/tools/bin/execsql $script $log TWH_MART $ctrluser $ctrlpass TWH_MART $ctrluser $ctrlpass";
        `$cmd`;

        $rc = $?;
    }
    
    $rc >>=8;
    return $rc;


    
}

exit 0
