############################################################################
#
#  Licensed Materials - Property of IBM
#  5698-NVW
#
#  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
#
#  US Government Users Restricted Rights - Use, duplication or
#  disclosure restricted by GSA ADP Schedule Contract with
#  IBM Corp.
#
#   File Name: ..\misc\anm_collapse_outages.pl
#   
#  
############################################################################
#!/usr/bin/perl

use Time::Local;

if (! @ARGV) {
    $log = 'anm_collapse_outages.log';
    if (! open(LOG, ">$log")) {
        print "Collapse Outages Error: Unable to open the specified log file for writing:\n";
        print "\n    \"$log\".\n\n";
        print "$!\n";
        exit(1);
    }
    print LOG "\nCollapse Outages Error: a file name is required.\n\n";
    usage(1);
}

$log = $ARGV[0].'.log';
if (! open(LOG, ">$log")) {
    print "\nCollapse Outages Error: Unable to open the specified log file for writing:\n";
    print "\n    \"$log\".\n\n";
    print "$!\n";
    exit(1);
    }
print LOG "Logfile $log opened.\n";

$hfile = $ARGV[0].'.preedit';
if (! open(HOSTS, "<$hfile")) {
    print LOG "\nCollapse Outages Error: unable to open the specified hostname file for reading:\n";
    print LOG "\n    \"$hfile\".\n\n";
    print LOG "$!\n";
    close(LOG);
    exit(1);
}

$out = $ARGV[0].'.postedit';
 if (! open(OUT, ">$out")) {
        print LOG "\nCollapse Outages Error: Unable to open the specified output file for writing:\n";
        print LOG "\n    \"$out\".\n\n";
        print LOG "$!\n";
        close(LOG);
        exit(1);
    }


$continueProcessing = 1;
$nextLineToProcess = "no line";


while ($continueProcessing == 1) {
    if ( $nextLineToProcess eq 'no line' ) {
   	if ( not ( $nextLineToProcess = <HOSTS> ) )  {
	    $continueProcessing = 0;
	    next;
	}
    }   

    $inline = $nextLineToProcess;  
    
    @inlist = split_commas($inline);
    print LOG "\n>>Processing Input: \"$inlist[0]\",\"$inlist[1]\",\"$inlist[2]\",\"$inlist[3]\",\"$inlist[4]\",\"$inlist[5]\",\"$inlist[6]\"\n";
    @outline = ();
    $outline[0] = $inlist[0];
    $outline[1] = $inlist[1];
    $outline[2] = $inlist[2];
    $outline[3] = $inlist[3];
    $outline[5] = $inlist[5];
    $outline[6] = $inlist[6];

    if ( $inlist[4] eq "9999-01-01-00.00.00.000000" ) {

	$readAnother = 1;
	@nextlist = ();
	$nextline = "no line";

	while ( $readAnother == 1 ) {

	    @nextlist = ();

	    if ( $nextline = <HOSTS> ) {
		@nextlist = split_commas($nextline);
		if ( ($nextlist[4] ne "9999-01-01-00.00.00.000000") || 
		     ($nextlist[3] ne "9999-01-01-00.00.00.000000") ||
		     ( $nextlist[1] != $inlist[1]) ) {
		    $readAnother = 0;
		}
	    }
	    else {
		print LOG "\nCollapse Outages Error: expecting another outage row for component:";
		print LOG " \"$outline[0]\".\n";
		%nextlist = ('0', '0', '0', '0', "9999-01-01-00.00.00.000000");		
		$nextline = "no line";
		$readAnother = 0;
	    }
	}
	
	if ( ($nextlist[1] == $inlist[1]) &&
	     ($nextlist[3] eq "9999-01-01-00.00.00.000000") ) {
	    $outline[4] = $nextlist[4];
	    
	    $nextLineToProcess = "no line";
	}
	else {
	    $outline[4] = $inlist[4];

	    if ( $nextline ne "no line" ) {
		$nextLineToProcess = $nextline;
	    }
	    else {
		$nextLineToProcess = "no line";
	    }
	}
	     

	# $outline[4] = $nextlist[4];
    }
    else {
	$outline[4] = $inlist[4];
	$nextLineToProcess = "no line";
    }

# JMP February 18, 2004 PJ29588

$outline[0] = trim($outline[0]);
$outline[1] = trim($outline[1]);
$outline[2] = trim($outline[2]);
$outline[3] = trim($outline[3]);
$outline[4] = trim($outline[4]);
$outline[6] = trim($outline[6]);

    
     print OUT "\"$outline[0]\",\"$outline[1]\",\"$outline[2]\",\"$outline[3]\",\"$outline[4]\",\"0\",\"$outline[6]\"\n";
    
}

print LOG "\nEnd of Input.\n";
print LOG "End of Processing.\n";

close(HOSTS);
close(OUT);
close(LOG);

exit(0);

sub usage {
    $rc = @_;
    print LOG <<USAGE;
anm_collapse_outages.pl <HOSTS_FILE>\n
	where HOSTS_FILE.preedit is a csv file with 'hostname','status','start_time','end_time'
USAGE
    close(LOG);
    exit($rc);
}

sub split_commas {
    my $line = shift;
    my @listitems = ();
    push(@listitems, $+) while $line =~ m{
    "([^\"\\]*(?:\\.[^\"\\]*)*)",?
      |  ([^,]+),?
      | ,
    }gx;
    push(@listitems, undef) if substr($line, -1,1) eq ',';
    return @listitems;
}

# JMP February 18, 2004 PJ29588

sub trim($)
{
$outline = shift ;
$outline =~ s/^\s+// ;
$outline =~ s/\s+$// ;
return $outline ;
}
