############################################################################
#
#  Licensed Materials - Property of IBM
#  5698-NVW
#
#  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
#
#  US Government Users Restricted Rights - Use, duplication or
#  disclosure restricted by GSA ADP Schedule Contract with
#  IBM Corp.
#
#   File Name: ..\misc\anm_split_outages.pl
#  
#  
############################################################################
#!/usr/bin/perl

use Time::Local;

if (! @ARGV) {
    $log = 'anm_split_outages.log';
    if (! open(LOG, ">$log")) {
        print "Split Outages Error: Unable to open the specified log file for writing:\n";
        print "\n    \"$log\".\n\n";
        print "$!\n";
        exit(1);
    }
    print LOG "\nSplit Outages Error: a file name is required.\n\n";
    usage(1);
}

$log = $ARGV[0].'.log';
if (! open(LOG, ">$log")) {
    print "\nSplit Outages Error: Unable to open the specified log file for writing:\n";
    print "\n    \"$log\".\n\n";
    print "$!\n";
    exit(1);
    }
print LOG "Logfile $log opened.\n";

$hfile = $ARGV[0].'.preedit';
if (! open(HOSTS, "<$hfile")) {
    print LOG "\nSplit Outages Error: unable to open the specified hostname file for reading:\n";
    print LOG "\n    \"$hfile\".\n\n";
    print LOG "$!\n";
    close(LOG);
    exit(1);
}

 $out = $ARGV[0].'.postedit';
 if (! open(OUT, ">$out")) {
        print LOG "\nSplit Outages Error: Unable to open the specified output file for writing:\n";
        print LOG "\n    \"$out\".\n\n";
        print LOG "$!\n";
        close(LOG);
        exit(1);
    }


while ($inline = <HOSTS>) {
    @inlist = split_commas($inline);
    print LOG "\n>>Processing Input: \"$inlist[0]\",\"$inlist[1]\",\"$inlist[2]\",\"$inlist[3]\"\n";
    @outline = ();
    
    $outline[0] = $inlist[0];
    $inlist[1] =~ s/\s+$//;
    $outline[1] = $inlist[1];


    $inlist[2] =~ s/\s+$//;
    $inlist[3] =~ s/\s+$//;

    @times = ();
    @times2 = ();

    @times = split(/-/, $inlist[2]);
    @times2 = split(/\./, $times[3]);
    
    $temptime = timegm($times2[2], $times2[1], $times2[0], $times[2], $times[1] - 1, $times[0] - 1900);

    @start = gmtime($temptime);

    @times = ();
    @times2 = ();
    
    @times = split(/-/, $inlist[3]);
    @times2 = split(/\./, $times[3]);
    
    $temptime = timegm($times2[2], $times2[1], $times2[0], $times[2], $times[1] - 1, $times[0] - 1900);

    @end = gmtime($temptime);

    if ( ($start[2] == $end[2]) && ($start[7] == $end[7]) && ($start[5] == $end[5]) ) {
	$outline[2] = $inlist[2];
	$outline[3] = $inlist[3];


	#JMP February 18, 2004 PJ29588

	$outline[0] = trim($outline[0]);
	$outline[1] = trim($outline[1]);
	$outline[2] = trim($outline[2]);
	$outline[3] = trim($outline[3]);


	print OUT "\"$outline[0]\",\"$outline[1]\",\"$outline[2]\",\"$outline[3]\",\"0\",\"0\"\n";
    }
    else {
	
	while ( (($start[2] != $end[2]) || 
		      ($start[7] != $end[7])) 
		&& ($start[5] <= $end[5]) ) 
	{
	    
	    $ttime = timegm(59, 59, $start[2], $start[3], $start[4], $start[5]);
	    @tempoutline2 = ();
	    @tempoutline2 = @start;
	    @tempoutline3 = ();
	    @tempoutline3 = gmtime($ttime);

            #JMP February 18, 2004 PJ29588

            $outline[0] = trim($outline[0]);
            $outline[1] = trim($outline[1]);
	      
	    print OUT "\"$outline[0]\",\"$outline[1]\",\"";
	    $tyear= $tempoutline2[5] + 1900;
	    $tmon = $tempoutline2[4] + 1;
	    $tday = $tempoutline2[3];
	    $thour = $tempoutline2[2];
	    $tmin = $tempoutline2[1];
	    $tsec = $tempoutline2[0];
	    print OUT "$tyear-$tmon-$tday-$thour\.";
	    if ( $tmin < 10 ) {
		print OUT "0";
	    }
	    print OUT "$tmin\.";
	    if ( $tsec < 10 ) {
		print OUT "0";
	    }
	    print OUT "$tsec\.000000\",\"";
	    $tyear = $tempoutline3[5] + 1900;
	    $tmon = $tempoutline3[4] + 1;
	    $tday = $tempoutline3[3];
	    $thour = $tempoutline3[2];
	    $tmin = $tempoutline3[1];
	    $tsec = $tempoutline3[0];
	    print OUT "$tyear-$tmon-$tday-$thour\.";
	    if ( $tmin < 10 ) {
		print OUT "0";
	    }
	    print OUT "$tmin\.";
	    if ( $tsec < 10 ) {
		print OUT "0";
	    }
	    print OUT "$tsec\.000000\",\"0\",\"0\"\n";

	    @start = gmtime($ttime + 1);
		
	}

       
	@tempoutline2 = ();
	@tempoutline2 = @start;
	@tempoutline3 = ();
	@tempoutline3 = @end;

	#JMP February 18, 2004 PJ29588.

	$outline[0] = trim($outline[0]);
	$outline[1] = trim($outline[1]);

	print OUT "\"$outline[0]\",\"$outline[1]\",\"";
	$tyear= $tempoutline2[5] + 1900;
	$tmon = $tempoutline2[4] + 1;
	$tday = $tempoutline2[3];
	$thour = $tempoutline2[2];
	$tmin = $tempoutline2[1];
	$tsec = $tempoutline2[0];
	print OUT "$tyear-$tmon-$tday-$thour\.";
	if ( $tmin < 10 ) {
	    print OUT "0";
	}
	print OUT "$tmin\.";
	if ( $tsec < 10 ) {
	    print OUT "0";
	}
	print OUT "$tsec\.000000\",\"";
	$tyear= $tempoutline3[5] + 1900;
	$tmon = $tempoutline3[4] + 1;
	$tday = $tempoutline3[3];
	$thour = $tempoutline3[2];
	$tmin = $tempoutline3[1];
	$tsec = $tempoutline3[0];
	print OUT "$tyear-$tmon-$tday-$thour\.";
	if ( $tmin < 10 ) {
	    print OUT "0";
	}
	print OUT "$tmin\.";
	if ( $tsec < 10 ) {
	    print OUT "0";
	}
	print OUT "$tsec\.000000\",\"0\",\"0\"\n";
    }    

}    

print LOG "\nEnd of Input.\n";
print LOG "End of Processing.\n";

close(HOSTS);
close(OUT);
close(LOG);

exit(0);

sub usage {
    $rc = @_;
    print LOG <<USAGE;
anm_split_outages.pl <HOSTS_FILE>\n
	where HOSTS_FILE.preedit is a csv file with 'hostname','status','start_time','end_time'
USAGE
    close(LOG);
    exit($rc);
}

sub split_commas {
    my $line = shift;
    my @listitems = ();
    push(@listitems, $+) while $line =~ m{
    "([^\"\\]*(?:\\.[^\"\\]*)*)",?
      |  ([^,]+),?
      | ,
    }gx;
    push(@listitems, undef) if substr($line, -1,1) eq ',';
    return @listitems;
}

#JMP February 18, 2004 PJ29588

sub trim($)
{
$outline = shift ;
$outline =~ s/^\s+// ;
$outline =~ s/\s+$// ;
return $outline ;
}


